@@ -8,7 +8,7 @@ use Encode qw/encode/;
 use HTML::FormatText;
 use WebService::TDWTF;
 
-our $VERSION = '0.001';
+our $VERSION = '0.003';
 
 sub print_list {
 	my $idlen = length $_[0]->Id;
@@ -24,10 +24,20 @@ sub print_article {
 	say HTML::FormatText->format_string($art->Body)
 }
 
+sub print_series {
+	for my $series (tdwtf_series) {
+		$series->{$_} = encode 'UTF-8', ($series->{$_} // '') for keys %$series;
+		say $series->{Slug}, ' ', $series->{Title}, "\n", $series->{Description}, "\n";
+	}
+}
+
 sub run {
 	my ($args, @argv) = @_;
+	return print_series if $args->{show_series};
 	return print_list tdwtf_list_recent @argv if $args->{recent};
 	return print_list tdwtf_list_series @argv if $args->{series};
 	return print_list tdwtf_list_author @argv if $args->{author};
 	print_article tdwtf_article @argv
 }
+
+1;
